==> haskell-postgresql-binary-0.12.1.1-60-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-binary
version: 0.12.1.1
id: postgresql-binary-0.12.1.1-Flpb0WsRvTqC8cFsYj6SF0
key: postgresql-binary-0.12.1.1-Flpb0WsRvTqC8cFsYj6SF0
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/postgresql-binary
synopsis: Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.
    .
    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql "hasql">
    is based on this library.
    .
    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.
category: PostgreSQL, Database, Codecs, Parsing
abi: 06a5cc6fe301442d515b0a365e7c719c
exposed: True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding
hidden-modules: PostgreSQL.Binary.Encoding.Builders
                PostgreSQL.Binary.Prelude PostgreSQL.Binary.Integral
                PostgreSQL.Binary.Interval PostgreSQL.Binary.Numeric
                PostgreSQL.Binary.Time PostgreSQL.Binary.Inet
                PostgreSQL.Binary.BuilderPrim
import-dirs: /usr/lib/ghc-8.6.2/site-local/postgresql-binary-0.12.1.1
library-dirs: /usr/lib/ghc-8.6.2/site-local/postgresql-binary-0.12.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/postgresql-binary-0.12.1.1
hs-libraries: HSpostgresql-binary-0.12.1.1-Flpb0WsRvTqC8cFsYj6SF0
depends:
    aeson-1.4.1.0-LhGJkSbQXa4Bc1ggOsS4Ag base-4.12.0.0
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    binary-parser-0.5.5-866InpOrEMPHVYzuG3f7c5 bytestring-0.10.8.2
    bytestring-strict-builder-0.4.5.1-HGrdfDuIbVh60p4EjWixcR
    containers-0.6.0.1 loch-th-0.2.2-3CPdVoaGmAI4E58ziaHpq7
    network-ip-0.3.0.2-BDcYoTCcngxIT3bdMuLq3T
    placeholders-0.1-BvqrCQDGi4R6ufjrVRZiOw
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi text-1.2.3.1 time-1.8.0.2
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    uuid-1.3.13-8JD8aeFgvIZ76tj03ZzkIs
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock
haddock-html: /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-binary-0.12.1.2-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-binary
version: 0.12.1.2
id: postgresql-binary-0.12.1.2-LnK39LgVTbaLZqwqL0UJQj
key: postgresql-binary-0.12.1.2-LnK39LgVTbaLZqwqL0UJQj
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/postgresql-binary
synopsis: Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.
    .
    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql "hasql">
    is based on this library.
    .
    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.
category: PostgreSQL, Database, Codecs, Parsing
abi: 1ea70c9a8b0a43c2c70b29ad80a6db93
exposed: True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding
hidden-modules: PostgreSQL.Binary.Encoding.Builders
                PostgreSQL.Binary.Prelude PostgreSQL.Binary.Integral
                PostgreSQL.Binary.Interval PostgreSQL.Binary.Numeric
                PostgreSQL.Binary.Time PostgreSQL.Binary.Inet
                PostgreSQL.Binary.BuilderPrim
import-dirs: /usr/lib/ghc-8.6.3/site-local/postgresql-binary-0.12.1.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/postgresql-binary-0.12.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/postgresql-binary-0.12.1.2
hs-libraries: HSpostgresql-binary-0.12.1.2-LnK39LgVTbaLZqwqL0UJQj
depends:
    aeson-1.4.2.0-BdBVLho0lrWC4iPoef6lEw base-4.12.0.0
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    binary-parser-0.5.5-866InpOrEMPHVYzuG3f7c5 bytestring-0.10.8.2
    bytestring-strict-builder-0.4.5.1-Eqd8yZ5UNRaQKIStuw9Gk
    containers-0.6.0.1 loch-th-0.2.2-3CPdVoaGmAI4E58ziaHpq7
    network-ip-0.3.0.2-4DmH0CsZrPE2xETlgtWBv3
    placeholders-0.1-BvqrCQDGi4R6ufjrVRZiOw
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi text-1.2.3.1 time-1.8.0.2
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    uuid-1.3.13-8JD8aeFgvIZ76tj03ZzkIs
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock
haddock-html: /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
